*********************
BinaryConfusionMatrix
*********************

A statistical class to handle operations involving binary predictions.

.. autoclass:: gouda.BinaryConfusionMatrix
  :members:
  :special-members:
